/******************************************************************************
 Multiple task example
 This program creates 2 tasks and send prints messages from each.
  
 *****************************************************************************/
#include "predef.h"
#include <stdio.h>
#include <ctype.h>
#include <startnet.h>
#include <autoupdate.h>
#include <ucos.h>
#include <dhcpclient.h>
#include <netinterface.h>


//----- function prototypes -----
extern "C"
{
   void UserMain( void *pd );
}

DWORD MyTaskStack[USER_TASK_STK_SIZE];


/*-------------------------------------------------------------------
 MyTask
 ------------------------------------------------------------------*/
void MyTask( void *pdata )
{
   WORD data = *( WORD * ) pdata;  // cast passed parameter

   iprintf( "Data passed to MyTask(): %d\r\n", data );

   while ( 1 )
   {
      iprintf( "     Message from MyTask()\r\n" );
      OSTimeDly( TICKS_PER_SECOND );  // this is a blocking call
   }
}


/*-------------------------------------------------------------------
 UserMain
 ------------------------------------------------------------------*/
void UserMain( void *pd )
{
   InitializeStack();
   OSChangePrio( MAIN_PRIO );

   int EthernetInterface = GetFirstInterface();  // Get first interface identifier
   InterfaceBlock *ib = GetInterFaceBlock( EthernetInterface );  // Get interface data
   if (ib->netIP == 0)  // Check IP address for 0.0.0.0, and use DHCP if necessary
   {
      iprintf( "\r\nNo static IP address set, attempting DHCP\r\n");
      if ( GetDHCPAddress() != DHCP_OK )
         iprintf("*** DHCP Failed \r\n");
      else
         iprintf( "DHCP IP Address: ");
   }
   else
      iprintf("Static IP Address: ");
   ShowIP(ib->netIP); iprintf("\r\n");    

   EnableAutoUpdate();

   // This example passes data to the task, but this is optional
   WORD  MyTaskData = 1234;   

   /* Create and launch the task. Note that we selected a priority of 
      MAIN_PRIO+1, which means the new task is of lower priority than UserMain. 
      The implication is that if UserMain does not block, MyTask will never 
      run.
   */
   if ( OSTaskCreate( MyTask,
                      ( void * ) &MyTaskData,
                      ( void * ) &MyTaskStack[USER_TASK_STK_SIZE],
                      ( void * ) MyTaskStack,
                      MAIN_PRIO + 1 ) != OS_NO_ERR )
   {
      iprintf( "*** Error creating task\r\n" );
   }

   while ( 1 )
   {
      OSTimeDly( TICKS_PER_SECOND * 2 );
      iprintf( "Message from UserMain()\r\n" );
   }
}









